/**
  **************************************************************************
  * @file     at32f403a_407_int.c
  * @version  v2.0.2
  * @date     2021-10-27
  * @brief    main interrupt service routines.
  **************************************************************************
  *                       Copyright notice & Disclaimer
  *
  * The software Board Support Package (BSP) that is made available to 
  * download from Artery official website is the copyrighted work of Artery. 
  * Artery authorizes customers to use, copy, and distribute the BSP 
  * software and its related documentation for the purpose of design and 
  * development in conjunction with Artery microcontrollers. Use of the 
  * software is governed by this copyright notice and the following disclaimer.
  *
  * THIS SOFTWARE IS PROVIDED ON "AS IS" BASIS WITHOUT WARRANTIES,
  * GUARANTEES OR REPRESENTATIONS OF ANY KIND. ARTERY EXPRESSLY DISCLAIMS,
  * TO THE FULLEST EXTENT PERMITTED BY LAW, ALL EXPRESS, IMPLIED OR
  * STATUTORY OR OTHER WARRANTIES, GUARANTEES OR REPRESENTATIONS,
  * INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
  *
  **************************************************************************
  */

/* includes ------------------------------------------------------------------*/
#include "at32f403a_407_int.h"
#include "at32f403a_407_clock.h"
#include "stdio.h"

/** @addtogroup UTILITIES_examples
  * @{
  */
	
extern uint32_t Counter_1;
extern uint32_t Counter_2;
extern uint32_t Last_Counter_1;
extern uint32_t Last_Counter_2;
__IO uint32_t Counter_Value = 0;
__IO uint32_t Counter_Value_1 = 0;
__IO uint32_t Counter_Value_2 = 0;
float Duty_Ration_Value = 0;
extern uint32_t SystemCoreClock;

/** @addtogroup 403A_TMR_pwm_input_test TMR_pwm_input
  * @{
  */

/**
  * @brief  this function handles nmi exception.
  * @param  none
  * @retval none
  */
void NMI_Handler(void)
{
}

/**
  * @brief  this function handles hard fault exception.
  * @param  none
  * @retval none
  */
void HardFault_Handler(void)
{
  /* go to infinite loop when hard fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  this function handles memory manage exception.
  * @param  none
  * @retval none
  */
void MemManage_Handler(void)
{
  /* go to infinite loop when memory manage exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  this function handles bus fault exception.
  * @param  none
  * @retval none
  */
void BusFault_Handler(void)
{
  /* go to infinite loop when bus fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  this function handles usage fault exception.
  * @param  none
  * @retval none
  */
void UsageFault_Handler(void)
{
  /* go to infinite loop when usage fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  this function handles svcall exception.
  * @param  none
  * @retval none
  */
void SVC_Handler(void)
{
}

/**
  * @brief  this function handles debug monitor exception.
  * @param  none
  * @retval none
  */
void DebugMon_Handler(void)
{
}

/**
  * @brief  this function handles pendsv_handler exception.
  * @param  none
  * @retval none
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  this function handles systick handler.
  * @param  none
  * @retval none
  */
void SysTick_Handler(void)
{
}

/**
  * @brief  This TMR5 update interrupt: Enter interruption every 1s
  * @param  None
  * @retval None
  */
#if defined(high_frequency_test)
void TMR5_GLOBAL_IRQHandler(void)
{
  
  Counter_1 = TMR2->cval;
  if(Counter_1>=Last_Counter_1)
  {
    Counter_Value =  Counter_1 -Last_Counter_1;
  }else{
    Counter_Value =  0xFFFFFFFF -Last_Counter_1+Counter_1;
  }
  printf("High Frequency : %d Hz\r\n",Counter_Value);
  Last_Counter_1 = Counter_1 ;
    
  /* Clear TMR5 update Interrupt  pending bit */
  tmr_flag_clear(TMR5, TMR_OVF_FLAG);
}

#elif defined(low_frequency_test)	

void TMR2_GLOBAL_IRQHandler(void)
{
  Counter_1 = TMR2->cval;

  if(Counter_1>=Last_Counter_1)
  {
    Counter_Value =  Counter_1 -Last_Counter_1;
  }else{
    Counter_Value =  0xFFFFFFFF -Last_Counter_1+Counter_1;
  }
  printf("Low Frequency : %f mhz\r\n",((float)SystemCoreClock/Counter_Value)*1000);
  Last_Counter_1 = Counter_1 ;
  
  /* Clear TMR2 Capture compare interrupt pending bit */
  tmr_flag_clear(TMR2, TMR_C1_FLAG);
}

#elif defined(duty_ration_test)

void TMR1_OVF_TMR10_IRQHandler(void)
{
  
  Counter_1 = TMR2->cval;
  Counter_2 = TMR5->cval;
  if(Counter_1>=Last_Counter_1)
  {
    Counter_Value_1 =  Counter_1 -Last_Counter_1;
  }else{
    Counter_Value_1 =  0xFFFFFFFF -Last_Counter_1+Counter_1;
  }
  
  if(Counter_2>=Last_Counter_2)
  {
    Counter_Value_2 =  Counter_2 -Last_Counter_2;
  }else{
    Counter_Value_2 =  0xFFFFFFFF -Last_Counter_2+Counter_2;
  }
  
  Duty_Ration_Value = (float)Counter_Value_1/(Counter_Value_1+Counter_Value_2);
  printf("Duty Ration : %f %%\r\n",Duty_Ration_Value*100);
  
  Last_Counter_1 = Counter_1 ;
  Last_Counter_2 = Counter_2 ;
  
  
  /* Clear TMR1 update Interrupt  pending bit */
  tmr_flag_clear(TMR1, TMR_OVF_FLAG);
}
#endif


/**
  * @}
  */ 

/**
  * @}
  */
