/**
  **************************************************************************
  * @file     main.c
  * @version  v2.0.2
  * @date     2021-10-27
  * @brief    main program
  **************************************************************************
  *                       Copyright notice & Disclaimer
  *
  * The software Board Support Package (BSP) that is made available to 
  * download from Artery official website is the copyrighted work of Artery. 
  * Artery authorizes customers to use, copy, and distribute the BSP 
  * software and its related documentation for the purpose of design and 
  * development in conjunction with Artery microcontrollers. Use of the 
  * software is governed by this copyright notice and the following disclaimer.
  *
  * THIS SOFTWARE IS PROVIDED ON "AS IS" BASIS WITHOUT WARRANTIES,
  * GUARANTEES OR REPRESENTATIONS OF ANY KIND. ARTERY EXPRESSLY DISCLAIMS,
  * TO THE FULLEST EXTENT PERMITTED BY LAW, ALL EXPRESS, IMPLIED OR
  * STATUTORY OR OTHER WARRANTIES, GUARANTEES OR REPRESENTATIONS,
  * INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
  *
  **************************************************************************
  */

#include "at32f403a_407_clock.h"

/** @addtogroup UTILITIES_examples
  * @{
  */
	
/** @addtogroup 403A_TMR_pwm_input_test TMR_pwm_output
  * @{
  */

tmr_output_config_type tmr_output_struct;

void crm_configuration(void);
void gpio_configuration(void);

/**
  * @brief  configures the different system clocks.
  * @param  none
  * @retval none
  */
void crm_configuration(void)
{
  /* tmr1 clock enable */
  crm_periph_clock_enable(CRM_TMR1_PERIPH_CLOCK, TRUE);
	
  /* gpioa clock enable */
  crm_periph_clock_enable(CRM_GPIOA_PERIPH_CLOCK, TRUE);
}

/**
  * @brief  configure the tmr pins.
  * @param  none
  * @retval none
  */
void gpio_configuration(void)
{
  gpio_init_type gpio_init_struct;

  gpio_default_para_init(&gpio_init_struct);

  gpio_init_struct.gpio_pins = GPIO_PINS_8;
  gpio_init_struct.gpio_mode = GPIO_MODE_MUX;
	gpio_init_struct.gpio_out_type = GPIO_OUTPUT_PUSH_PULL;
  gpio_init_struct.gpio_pull = GPIO_PULL_NONE;	
  gpio_init_struct.gpio_drive_strength = GPIO_DRIVE_STRENGTH_STRONGER;
  gpio_init(GPIOA, &gpio_init_struct);
}

/**
  * @brief  main function.
  * @param  none
  * @retval none
  */
int main(void)
{
  /* system clocks configuration */
	system_clock_config();
  crm_configuration();

  /* gpio configuration */
  gpio_configuration();

	#if defined(Output_High_Frequency)
	
  /* PA8 Output 60Mhz */
	crm_clock_out_set(CRM_CLKOUT_PLL_DIV_4);
	
  #elif defined(Output_Low_Frequency)
	
  /* PA8 Output 500mhz */
	tmr_reset(TMR1);
	tmr_base_init(TMR1, 24000-1, 20000-1);
  tmr_cnt_dir_set(TMR1, TMR_COUNT_UP);
	
  /* channel configuration in output mode */	
	tmr_output_default_para_init(&tmr_output_struct);
  tmr_output_struct.oc_mode = TMR_OUTPUT_CONTROL_PWM_MODE_A;
  tmr_output_struct.oc_output_state = TRUE;
  /* channel 1 */	
  tmr_output_channel_config(TMR1, TMR_SELECT_CHANNEL_1, &tmr_output_struct);
  tmr_channel_value_set(TMR1, TMR_SELECT_CHANNEL_1, 24000/2);

  /* output enable */
  tmr_output_enable(TMR1, TRUE);
  
  /* enable tmr1 */
  tmr_counter_enable(TMR1, TRUE);
	
	#elif defined(Output_PWM_Duty_Ration_10)
	
  /* PA8 Output 10% Duty ,6MHz*/
	tmr_reset(TMR1);
	tmr_base_init(TMR1, 40-1, 0);
  tmr_cnt_dir_set(TMR1, TMR_COUNT_UP);
	
  /* channel configuration in output mode */	
	tmr_output_default_para_init(&tmr_output_struct);
  tmr_output_struct.oc_mode = TMR_OUTPUT_CONTROL_PWM_MODE_A;
  tmr_output_struct.oc_output_state = TRUE;

  /* channel 1 */	
  tmr_output_channel_config(TMR1, TMR_SELECT_CHANNEL_1, &tmr_output_struct);
  tmr_channel_value_set(TMR1, TMR_SELECT_CHANNEL_1, 4);

  /* output enable */
  tmr_output_enable(TMR1, TRUE);
  
  /* enable tmr1 */
  tmr_counter_enable(TMR1, TRUE);
	
  #endif	
	
	
  while(1)
  {
  }
}

/**
  * @}
  */ 

/**
  * @}
  */ 
